@@ -53,6 +53,7 @@ import io
 import itertools
 import optparse
 import os
+import os.path
 import re
 import shlex
 import shutil
@@ -126,11 +127,11 @@ class LogParser(object):
     TIMESTAMP_REGEXP = re.compile(r'^(\d+) +')
     NICK_REGEXP = re.compile(r'^<(.*?)(!.*?)?>\s')
     DIRCPROXY_NICK_REGEXP = re.compile(r'^<(.*?)(!.*)?>\s[\+-]?')
-    JOIN_REGEXP = re.compile(r'^(?:\*\*\*|-->)\s.*joined')
-    PART_REGEXP = re.compile(r'^(?:\*\*\*|<--)\s.*(quit|left)')
-    SERVMSG_REGEXP = re.compile(r'^(?:\*\*\*|---)\s')
+    JOIN_REGEXP = re.compile(r'^(?:\*\*\*|-->|-!-)\s.*joined')
+    PART_REGEXP = re.compile(r'^(?:\*\*\*|<--|-!-)\s.*(quit|left)')
+    SERVMSG_REGEXP = re.compile(r'^(?:\*\*\*|---|-!-)\s')
     NICK_CHANGE_REGEXP = re.compile(
-        r'^(?:\*\*\*|---)\s+(.*?) (?:are|is) now known as (.*)')
+        r'^(?:\*\*\*|---|-!-)\s+(.*?) (?:are|is) now known as (.*)')
 
     def __init__(self, infile, dircproxy=False):
         self.infile = infile
@@ -373,7 +374,7 @@ class AbstractStyle(object):
     description = "Single-line description"
     charset = 'US-ASCII'
 
-    def __init__(self, outfile, colours=None):
+    def __init__(self, outfile, *, outfilename='', colours=None):
         """Create a text formatter for writing to outfile.
 
         The ``colours`` dictionary may have the following items:
@@ -388,6 +389,7 @@ class AbstractStyle(object):
         self.outfile = io.TextIOWrapper(outfile, encoding=self.charset,
                                         errors='xmlcharrefreplace',
                                         line_buffering=True)
+        self.outfilename = os.path.basename(outfilename)
         self.colours = colours or {}
         self._anchors = set()
 
@@ -452,6 +454,7 @@ class SimpleTextStyle(AbstractStyle):
 \t<meta name="generator" content="irclog2html.py %(VERSION)s by Marius Gedminas">
 \t<meta name="version" content="%(VERSION)s - %(RELEASE)s">
 \t<meta http-equiv="Content-Type" content="text/html; charset=%(charset)s">
+\t<meta name="viewport" content="width=device-width, initial-scale=1">
 </head>
 <body text="#000000" bgcolor="#ffffff"><tt>""" % {
             'VERSION': VERSION,
@@ -569,6 +572,7 @@ class XHTMLStyle(AbstractStyle):
 <html>
 <head>
   <meta http-equiv="Content-Type" content="text/html; charset=%(charset)s" />
+  <meta name="viewport" content="width=device-width, initial-scale=1" />
   <title>%(title)s</title>
   <link rel="stylesheet" href="irclog.css" />
   <meta name="generator" content="irclog2html.py %(VERSION)s by Marius Gedminas" />
@@ -642,8 +646,9 @@ class XHTMLStyle(AbstractStyle):
         if time:
             print(
                 '<p id="{anchor}" class="{css_class}">'
-                '<a href="#{anchor}" class="time">{time}</a>'
+                '<a href="{outfilename}#{anchor}" class="time">{time}</a>'
                 ' {text}</p>'.format(
+                    outfilename=self.outfilename,
                     anchor=self.timestamp_anchor(time),
                     css_class=self.CLASSMAP[what],
                     time=shorttime(time),
@@ -669,11 +674,12 @@ class XHTMLStyle(AbstractStyle):
         if time:
             print(
                 '<p id="{anchor}" class="comment">'
-                '<a href="#{anchor}" class="time">{time}</a> '
+                '<a href="{outfilename}#{anchor}" class="time">{time}</a> '
                 '<span class="nick" style="color: {color}">'
                 '&lt;{nick}&gt;</span>'
                 ' <span class="text">{text}</span></p>'.format(
                     anchor=self.timestamp_anchor(time),
+                    outfilename=self.outfilename,
                     time=shorttime(time),
                     color=htmlcolour,
                     nick=nick,
@@ -712,7 +718,7 @@ class XHTMLTableStyle(XHTMLStyle):
                     anchor=self.timestamp_anchor(time),
                     css_class=self.CLASSMAP[what],
                     text=text,
-                    link=link,
+                    link=link or self.outfilename,
                     time=shorttime(time)),
                 file=self.outfile)
         else:
@@ -729,6 +735,7 @@ class XHTMLTableStyle(XHTMLStyle):
         text = escape(text)
         text = createlinks(text)
         text = text.replace('  ', '&nbsp;&nbsp;')
+        link = link or self.outfilename
         if time:
             print(
                 '<tr id="{anchor}">'
@@ -952,7 +959,7 @@ def main(argv=sys.argv):
                      % (parser.prog, outfilename, e))
         try:
             parser = LogParser(infile, dircproxy=options.dircproxy)
-            formatter = style(outfile, colours)
+            formatter = style(outfile, outfilename=outfilename, colours=colours)
             convert_irc_log(parser, formatter, title or filename,
                             prev, index, next, searchbox=options.searchbox)
             css_file = os.path.join(os.path.dirname(outfilename), 'irclog.css')
