@@ -136,6 +136,8 @@ def doctest_LogParser():
         None JOIN '*** someone joined #channel'
         >>> test('--> someone joined')
         None JOIN '--> someone joined'
+        >>> test('-!- someone has joined #channel')
+        None JOIN '-!- someone has joined #channel'
 
     ...PART...
 
@@ -143,6 +145,8 @@ def doctest_LogParser():
         None PART '*** someone quit'
         >>> test('<-- someone left #channel')
         None PART '<-- someone left #channel'
+        >>> test('-!- someone has quit #channel')
+        None PART '-!- someone has quit #channel'
 
     ...NICKCHANGE...
 
@@ -150,6 +154,8 @@ def doctest_LogParser():
         None NICKCHANGE ('*** X is now known as Y', 'X', 'Y')
         >>> test('--- X are now known as Y')
         None NICKCHANGE ('--- X are now known as Y', 'X', 'Y')
+        >>> test('-!- X is now known as Y')
+        None NICKCHANGE ('-!- X is now known as Y', 'X', 'Y')
 
     ...SERVER...
 
@@ -157,6 +163,8 @@ def doctest_LogParser():
         None SERVER '--- welcome to irc.example.org'
         >>> test('*** welcome to irc.example.org')
         None SERVER '*** welcome to irc.example.org'
+        >>> test('-!- welcome to irc.example.org')
+        None SERVER '-!- welcome to irc.example.org'
 
     All unrecognized lines are reported as OTHER
 
@@ -327,6 +335,7 @@ def doctest_SimpleTextStyle():
             <meta name="generator" content="irclog2html.py ... by Marius Gedminas">
             <meta name="version" content="...">
             <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+            <meta name="viewport" content="width=device-width, initial-scale=1">
         </head>
         <body text="#000000" bgcolor="#ffffff"><tt>
 
@@ -364,6 +373,7 @@ def doctest_SimpleTextStyle_colourful():
             <meta name="generator" content="irclog2html.py ... by Marius Gedminas">
             <meta name="version" content="...">
             <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+            <meta name="viewport" content="width=device-width, initial-scale=1">
         </head>
         <body text="#000000" bgcolor="#ffffff"><tt>
 
@@ -401,6 +411,7 @@ def doctest_TextStyle_colourful():
             <meta name="generator" content="irclog2html.py ... by Marius Gedminas">
             <meta name="version" content="...">
             <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+            <meta name="viewport" content="width=device-width, initial-scale=1">
         </head>
         <body text="#000000" bgcolor="#ffffff"><tt>
 
@@ -437,6 +448,7 @@ def doctest_SimpleTableStyle():
             <meta name="generator" content="irclog2html.py ... by Marius Gedminas">
             <meta name="version" content="...">
             <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+            <meta name="viewport" content="width=device-width, initial-scale=1">
         </head>
         <body text="#000000" bgcolor="#ffffff"><tt>
         <table cellspacing=3 cellpadding=2 border=0>
@@ -475,6 +487,7 @@ def doctest_TableStyle():
             <meta name="generator" content="irclog2html.py ... by Marius Gedminas">
             <meta name="version" content="...">
             <meta http-equiv="Content-Type" content="text/html; charset=iso-8859-1">
+            <meta name="viewport" content="width=device-width, initial-scale=1">
         </head>
         <body text="#000000" bgcolor="#ffffff"><tt>
         <table cellspacing=3 cellpadding=2 border=0>
@@ -511,6 +524,7 @@ def doctest_XHTMLStyle():
         <html>
         <head>
           <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+          <meta name="viewport" content="width=device-width, initial-scale=1" />
           <title>IRC logs of #channel for Monday, 2008-06-10</title>
           <link rel="stylesheet" href="irclog.css" />
           <meta name="generator" content="irclog2html.py ... by Marius Gedminas" />
@@ -568,6 +582,7 @@ def doctest_XHTMLStyle_with_navigation_and_searchbox():
         <html>
         <head>
           <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+          <meta name="viewport" content="width=device-width, initial-scale=1" />
           <title>IRC logs of #channel for Monday, 2008-06-10</title>
           <link rel="stylesheet" href="irclog.css" />
           <meta name="generator" content="irclog2html.py ... by Marius Gedminas" />
@@ -599,6 +614,7 @@ def doctest_XHTMLTableStyle():
         <html>
         <head>
           <meta http-equiv="Content-Type" content="text/html; charset=UTF-8" />
+          <meta name="viewport" content="width=device-width, initial-scale=1" />
           <title>IRC logs of #channel for Monday, 2008-06-10</title>
           <link rel="stylesheet" href="irclog.css" />
           <meta name="generator" content="irclog2html.py ... by Marius Gedminas" />
